@@ -8,7 +8,7 @@ use ruc::*;
 use serde::{Deserialize, Serialize};
 use std::{
     collections::{
-        btree_map::{Entry, Iter, Range},
+        btree_map::{Entry, IntoIter, Iter},
         BTreeMap,
     },
     fmt,
@@ -74,8 +74,12 @@ where
     }
 
     #[inline(always)]
-    pub fn range<R: RangeBounds<K>>(&self, range: R) -> Range<K, V> {
-        self.inner.range(range)
+    pub fn range<R: RangeBounds<K>>(&self, range: R) -> IntoIter<K, V> {
+        self.inner
+            .range(range)
+            .map(|(k, v)| (k.clone(), v.clone()))
+            .collect::<BTreeMap<_, _>>()
+            .into_iter()
     }
 
     #[inline(always)]
